@@ -457,12 +457,12 @@ about_activated (GSimpleAction  *action,
 }
 
 static GActionEntry app_entries[] = {
-	{ "new-window", new_window_activated, NULL, NULL, NULL },
-	{ "new-document", new_document_activated, NULL, NULL, NULL },
-	{ "preferences", preferences_activated, NULL, NULL, NULL },
-	{ "help", help_activated, NULL, NULL, NULL },
-	{ "about", about_activated, NULL, NULL, NULL },
-	{ "quit", _gedit_cmd_file_quit, NULL, NULL, NULL }
+	{ "new-window", new_window_activated },
+	{ "new-document", new_document_activated },
+	{ "preferences", preferences_activated },
+	{ "help", help_activated },
+	{ "about", about_activated },
+	{ "quit", _gedit_cmd_file_quit }
 };
 
 static void
@@ -669,9 +669,14 @@ init_tepl_settings (void)
 					     GEDIT_SETTINGS_USE_DEFAULT_FONT,
 					     GEDIT_SETTINGS_EDITOR_FONT);
 
-	tepl_settings_handle_simple_theme_variant (tepl_settings,
-						   ui_settings,
-						   GEDIT_SETTINGS_THEME_VARIANT);
+	tepl_settings_provide_style_scheme_settings (tepl_settings,
+						     editor_settings,
+						     GEDIT_SETTINGS_STYLE_SCHEME_FOR_LIGHT_THEME_VARIANT,
+						     GEDIT_SETTINGS_STYLE_SCHEME_FOR_DARK_THEME_VARIANT);
+
+	tepl_settings_handle_theme_variant (tepl_settings,
+					    ui_settings,
+					    GEDIT_SETTINGS_THEME_VARIANT);
 }
 
 static gchar *
@@ -707,10 +712,10 @@ gedit_app_startup (GApplication *application)
 
 	setup_theme_extensions (GEDIT_APP (application));
 
-	g_action_map_add_action_entries (G_ACTION_MAP (application),
-	                                 app_entries,
-	                                 G_N_ELEMENTS (app_entries),
-	                                 application);
+	amtk_action_map_add_action_entries_check_dups (G_ACTION_MAP (application),
+						       app_entries,
+						       G_N_ELEMENTS (app_entries),
+						       application);
 
 	/* menus */
 	if (!show_menubar ())
